@@ -1,9 +1,11 @@
 from fabricks.api.context import init_spark_session
 from fabricks.api.core import get_job, get_jobs, get_step
+from fabricks.api.deploy import Deploy
 
 __all__ = [
     "init_spark_session",
     "get_job",
     "get_jobs",
     "get_step",
+    "Deploy",
 ]
