@@ -1,5 +1,4 @@
-from fabricks.context import BRONZE, DBUTILS, GOLD, SECRET_SCOPE, SILVER, SPARK, init_spark_session
-from fabricks.context.runtime import pprint_runtime
+from fabricks.context import BRONZE, DBUTILS, GOLD, SECRET_SCOPE, SILVER, SPARK, init_spark_session, pprint_runtime
 from fabricks.core.jobs.base._types import Bronzes, Golds, Silvers, Steps
 
 # step
