@@ -1,11 +1,11 @@
 # Databricks notebook source
-# MAGIC %run ./add_fabricks
+# MAGIC %run ./add_missing_modules
 
 # COMMAND ----------
 
 from databricks.sdk.runtime import dbutils, display
 
-from fabricks.core.scripts import generate
+from fabricks.core.schedules import generate
 
 # COMMAND ----------
 
