@@ -1,4 +1,4 @@
-from fabricks.cdc.base import BaseCDC, ChangeDataCaptures
+from fabricks.cdc.base import AllowedChangeDataCaptures, BaseCDC
 from fabricks.cdc.cdc import CDC
 from fabricks.cdc.nocdc import NoCDC
 from fabricks.cdc.scd1 import SCD1
@@ -7,7 +7,7 @@ from fabricks.cdc.scd2 import SCD2
 __all__ = [
     "BaseCDC",
     "CDC",
-    "ChangeDataCaptures",
+    "AllowedChangeDataCaptures",
     "NoCDC",
     "SCD1",
     "SCD2",
