@@ -4,11 +4,12 @@ from typing import Any, List, Optional, Sequence, Union, cast
 
 from py4j.protocol import Py4JJavaError
 from pyspark.sql import DataFrame
-from pyspark.sql.connect.dataframe import DataFrame as CDataFrame
 
+from fabricks.cdc.base._types import AllowedSources
 from fabricks.cdc.base.configurator import Configurator
 from fabricks.context.log import DEFAULT_LOGGER
 from fabricks.metastore.table import SchemaDiff, Table
+from fabricks.utils._types import DataFrameLike
 from fabricks.utils.sqlglot import fix as fix_sql
 
 
@@ -18,13 +19,17 @@ class Generator(Configurator):
 
     def create_table(
         self,
-        src: Union[DataFrame, Table, str],
+        src: AllowedSources,
         partitioning: Optional[bool] = False,
         partition_by: Optional[Union[List[str], str]] = None,
         identity: Optional[bool] = False,
         liquid_clustering: Optional[bool] = False,
         cluster_by: Optional[Union[List[str], str]] = None,
         properties: Optional[dict[str, str]] = None,
+        masks: Optional[dict[str, str]] = None,
+        primary_key: Optional[dict[str, Any]] = None,
+        foreign_keys: Optional[dict[str, Any]] = None,
+        comments: Optional[dict[str, str]] = None,
         **kwargs,
     ):
         kwargs["mode"] = "complete"
@@ -37,7 +42,7 @@ class Generator(Configurator):
         if partitioning is True:
             assert partition_by, "partitioning column(s) not found"
 
-        df = self.reorder_columns(df)
+        df = self.reorder_dataframe(df)
 
         identity = False if identity is None else identity
         liquid_clustering = False if liquid_clustering is None else liquid_clustering
@@ -50,16 +55,20 @@ class Generator(Configurator):
             liquid_clustering=liquid_clustering,
             cluster_by=cluster_by,
             properties=properties,
+            masks=masks,
+            primary_key=primary_key,
+            foreign_keys=foreign_keys,
+            comments=comments,
         )
 
     def create_or_replace_view(self, src: Union[Table, str], schema_evolution: bool = True, **kwargs):
-        assert not isinstance(src, (DataFrame, CDataFrame)), "dataframe not allowed"
+        assert not isinstance(src, DataFrameLike), "dataframe not allowed"
 
         assert kwargs["mode"] == "complete", f"{kwargs['mode']} not allowed"
         sql = self.get_query(src, **kwargs)
 
         df = self.spark.sql(sql)
-        df = self.reorder_columns(df)
+        df = self.reorder_dataframe(df)
         columns = [f"`{c}`" for c in df.columns]
 
         sql = f"""
@@ -74,12 +83,12 @@ class Generator(Configurator):
         from __view
         """
         sql = fix_sql(sql)
-        DEFAULT_LOGGER.debug("create or replace view", extra={"job": self, "sql": sql})
+        DEFAULT_LOGGER.debug("create or replace view", extra={"label": self, "sql": sql})
 
         try:
             self.spark.sql(sql)
-        except Py4JJavaError:
-            DEFAULT_LOGGER.exception("could not execute sql query", extra={"job": self, "sql": sql})
+        except Py4JJavaError as e:
+            DEFAULT_LOGGER.exception("fail to execute sql query", extra={"label": self, "sql": sql}, exc_info=e)
 
     def optimize_table(self):
         columns = None
@@ -91,35 +100,34 @@ class Generator(Configurator):
 
         self.table.optimize(columns=columns)
 
-    def get_differences_with_deltatable(self, src: Union[DataFrame, Table, str], **kwargs) -> Optional[DataFrame]:
+    def get_differences_with_deltatable(self, src: AllowedSources, **kwargs) -> DataFrame:
+        from pyspark.sql.types import StringType, StructField, StructType
+
+        schema = StructType(
+            [
+                StructField("column", StringType(), False),
+                StructField("data_type", StringType(), True),
+                StructField("new_column", StringType(), True),
+                StructField("new_data_type", StringType(), True),
+                StructField("status", StringType(), True),
+            ]
+        )
+
         if self.is_view:
-            return None
+            return self.spark.createDataFrame([], schema=schema)
 
         else:
-            from pyspark.sql.types import StringType, StructField, StructType
-
             kwargs["mode"] = "complete"
             if "slice" in kwargs:
                 del kwargs["slice"]
 
             df = self.get_data(src, **kwargs)
-            df = self.reorder_columns(df)
+            df = self.reorder_dataframe(df)
+
             diffs = self.table.get_schema_differences(df)
-            df_diff = self.spark.createDataFrame(
-                [cast(Any, d.model_dump()) for d in diffs],
-                schema=StructType(
-                    [
-                        StructField("column", StringType(), False),
-                        StructField("data_type", StringType(), True),
-                        StructField("new_column", StringType(), True),
-                        StructField("new_data_type", StringType(), True),
-                        StructField("status", StringType(), True),
-                    ]
-                ),
-            )
-            return df_diff
+            return self.spark.createDataFrame([cast(Any, d.model_dump()) for d in diffs], schema=schema)
 
-    def get_schema_differences(self, src: Union[DataFrame, Table, str], **kwargs) -> Optional[Sequence[SchemaDiff]]:
+    def get_schema_differences(self, src: AllowedSources, **kwargs) -> Optional[Sequence[SchemaDiff]]:
         if self.is_view:
             return None
 
@@ -129,10 +137,11 @@ class Generator(Configurator):
                 del kwargs["slice"]
 
             df = self.get_data(src, **kwargs)
-            df = self.reorder_columns(df)
+            df = self.reorder_dataframe(df)
+
             return self.table.get_schema_differences(df)
 
-    def schema_drifted(self, src: Union[DataFrame, Table, str], **kwargs) -> Optional[bool]:
+    def schema_drifted(self, src: AllowedSources, **kwargs) -> Optional[bool]:
         d = self.get_schema_differences(src, **kwargs)
         if d is None:
             return None
@@ -140,13 +149,13 @@ class Generator(Configurator):
 
     def _update_schema(
         self,
-        src: Union[DataFrame, Table, str],
+        src: AllowedSources,
         overwrite: bool = False,
         widen_types: bool = False,
         **kwargs,
     ):
         if self.is_view:
-            assert not isinstance(src, (DataFrame, CDataFrame)), "dataframe not allowed"
+            assert not isinstance(src, DataFrameLike), "dataframe not allowed"
             self.create_or_replace_view(src=src)
 
         else:
@@ -155,14 +164,14 @@ class Generator(Configurator):
                 del kwargs["slice"]
 
             df = self.get_data(src, **kwargs)
-            df = self.reorder_columns(df)
+            df = self.reorder_dataframe(df)
             if overwrite:
                 self.table.overwrite_schema(df)
             else:
                 self.table.update_schema(df, widen_types=widen_types)
 
-    def update_schema(self, src: Union[DataFrame, Table, str], **kwargs):
+    def update_schema(self, src: AllowedSources, **kwargs):
         self._update_schema(src=src, **kwargs)
 
-    def overwrite_schema(self, src: Union[DataFrame, Table, str], **kwargs):
+    def overwrite_schema(self, src: AllowedSources, **kwargs):
         self._update_schema(src=src, overwrite=True, **kwargs)
