@@ -4,28 +4,30 @@ from typing import Optional, Union
 
 from jinja2 import Environment, PackageLoader
 from pyspark.sql import DataFrame
-from pyspark.sql.connect.dataframe import DataFrame as CDataFrame
 
+from fabricks.cdc.base._types import AllowedSources
 from fabricks.cdc.base.processor import Processor
 from fabricks.context.log import DEFAULT_LOGGER
-from fabricks.metastore.table import Table
 from fabricks.metastore.view import create_or_replace_global_temp_view
+from fabricks.utils._types import DataFrameLike
 from fabricks.utils.sqlglot import fix as fix_sql
 
 
 class Merger(Processor):
     def get_merge_context(self, src: Union[DataFrame, str], **kwargs) -> dict:
-        if isinstance(src, (DataFrame, CDataFrame)):
+        if isinstance(src, DataFrameLike):
             format = "dataframe"
-            columns = self.get_columns(src, backtick=False)
+            columns = self.get_columns(src, backtick=False, sort=False, check=False)  # already done in processor
         elif isinstance(src, str):
             format = "view"
-            columns = self.get_columns(f"select * from {src}", backtick=False)
+            columns = self.get_columns(
+                f"select * from {src}", backtick=False, sort=False, check=False
+            )  # already done in processor
         else:
             raise ValueError(f"{src} not allowed")
 
-        assert "__merge_key" in columns
-        assert "__merge_condition" in columns
+        assert "__merge_key" in columns, "__merge_key not found"
+        assert "__merge_condition" in columns, "__merge_condition not found"
 
         keys = kwargs.get("keys")
         if isinstance(keys, str):
@@ -35,6 +37,7 @@ class Merger(Processor):
         fields = [c for c in columns if not c.startswith("__")]
         where = kwargs.get("update_where") if self.table.rows > 0 else None
         soft_delete = "__is_deleted" in columns
+
         has_source = "__source" in columns
         has_key = "__key" in columns
         has_metadata = "__metadata" in columns
@@ -78,7 +81,7 @@ class Merger(Processor):
         try:
             sql = merge.render(**context)
         except Exception as e:
-            DEFAULT_LOGGER.debug("context", extra={"job": self, "content": context})
+            DEFAULT_LOGGER.debug("context", extra={"label": self, "content": context})
             raise e
 
         if fix:
@@ -86,23 +89,22 @@ class Merger(Processor):
                 sql = sql.replace("{src}", "src")
                 sql = fix_sql(sql)
                 sql = sql.replace("`src`", "{src}")
-                DEFAULT_LOGGER.debug("merge", extra={"job": self, "sql": sql})
+                DEFAULT_LOGGER.debug("merge", extra={"label": self, "sql": sql})
 
             except Exception as e:
-                DEFAULT_LOGGER.exception("could not clean sql query", extra={"job": self, "sql": sql})
+                DEFAULT_LOGGER.exception("fail to clean sql query", extra={"label": self, "sql": sql})
                 raise e
-        else:
-            DEFAULT_LOGGER.debug("merge", extra={"job": self, "sql": sql})
 
         return sql
 
-    def merge(self, src: Union[DataFrame, Table, str], **kwargs):
+    def merge(self, src: AllowedSources, **kwargs):
         if not self.table.exists():
             self.create_table(src, **kwargs)
 
         df = self.get_data(src, **kwargs)
         global_temp_view = f"{self.qualified_name}__merge"
-        view = create_or_replace_global_temp_view(global_temp_view, df, uuid=kwargs.get("uuid", False))
+        view = create_or_replace_global_temp_view(global_temp_view, df, uuid=kwargs.get("uuid", False), job=self)
 
         merge = self.get_merge_query(view, **kwargs)
+        DEFAULT_LOGGER.debug("exec merge", extra={"label": self, "sql": merge})
         self.spark.sql(merge, src=view)
