@@ -32,6 +32,7 @@ class RuntimeOptions(TypedDict):
     workers: int
     timeouts: RuntimeTimeoutOptions
     retention_days: int
+    timezone: Optional[str]
 
 
 class SparkOptions(TypedDict):
@@ -83,6 +84,7 @@ class TableOptions(TypedDict):
     liquid_clustering: Optional[bool]
     properties: Optional[dict[str, str]]
     retention_days: Optional[int]
+    masks: Optional[dict[str, str]]
 
 
 class Bronze(Step):
