@@ -12,7 +12,7 @@ class Fabricks(Databricks):
         }
 
 
-def fix(sql: str):
+def fix(sql: str, keep_comments: bool = True):
     sql = transpile(
         sql,
         "fabricks",
@@ -22,6 +22,7 @@ def fix(sql: str):
         normalize_functions="lower",
         leading_comma=True,
         max_text_width=119,
+        comments=keep_comments
     )[0]
     return sql
 
