@@ -1,5 +1,5 @@
 # Databricks notebook source
-# MAGIC %run ./add_fabricks
+# MAGIC %run ./add_missing_modules
 
 # COMMAND ----------
 
@@ -8,23 +8,17 @@ from logging import DEBUG
 from databricks.sdk.runtime import dbutils
 
 from fabricks.context.log import DEFAULT_LOGGER
-from fabricks.core.scripts.armageddon import armageddon
+from fabricks.deploy import Deploy
 from tests.integration._types import steps
 
 # COMMAND ----------
 
-print(steps)
-
-# COMMAND ----------
-
 DEFAULT_LOGGER.setLevel(DEBUG)
 
 # COMMAND ----------
 
-armageddon(steps=steps)
+Deploy.armageddon(steps=steps, nowait=True)  # why wait ?
 
 # COMMAND ----------
 
 dbutils.notebook.exit(value="exit (0)")  # type: ignore
-
-# COMMAND ----------
