@@ -131,3 +131,25 @@ def test_gold_fact_option():
 def test_gold_scd1_last_timestamp():
     last_timestamp = SPARK.sql("select * from gold.scd1_last_timestamp__last_timestamp").collect()[0][0]
     assert last_timestamp is None
+
+
+@pytest.mark.order(130)
+def test_gold_fact_no_drop():
+    j = get_job(step="gold", topic="fact", item="no_drop")
+
+    try:
+        j.drop()
+        assert False, "drop is allowed while no_drop is set"
+    except ValueError:
+        assert True, "drop not allowed while no_drop is set"
+
+
+@pytest.mark.order(131)
+def test_gold_fact_masker_and_commenter():
+    df = SPARK.sql("select dummy from gold.fact_masker_and_commenter order by 1 asc")
+
+    masked_value = df.select("dummy").collect()[0][0]
+    assert masked_value == "***", f"dummy {masked_value} <> ***"
+
+    masked_value = df.select("dummy").collect()[1][0]
+    assert masked_value == "2", f"dummy {masked_value} <> 2"
