@@ -1,5 +1,5 @@
 # Databricks notebook source
-# MAGIC %run ./add_fabricks
+# MAGIC %run ./add_missing_modules
 
 # COMMAND ----------
 
@@ -8,9 +8,9 @@ from typing import Any, cast
 
 from databricks.sdk.runtime import dbutils, display
 
-import fabricks.core.scripts as s
+import fabricks.core.schedules as s
+from fabricks.context import PATH_NOTEBOOKS
 from fabricks.context.log import DEFAULT_LOGGER
-from fabricks.context.runtime import PATH_NOTEBOOKS
 from fabricks.core import get_step
 from fabricks.core.jobs.base._types import TStep
 from fabricks.utils.helpers import run_in_parallel, run_notebook
